{{/*
    Helper functions for common contract inputs and outputs

    TODO - somewhere in these templates we should use http://masterminds.github.io/sprig/semver.html
           to compare .Chart.Version against Values.inputVersion for semantic version compatibility

*/}}


{{/*
    Private helper function for registry prefix
*/}}
{{- define "athena-utils._registryPrefix" -}}
{{ .Values.global.registryPrefix | default "harbor-repo.vmware.com/sbu-dev" }}
{{- end -}}

{{/*
    Private helper function for registry prefix with image
*/}}
{{- define "athena-utils.registryPrefixWithImage" -}}
{{- if .Values.infra.image -}}
{{ .Values.infra.image | quote }}
{{ else -}}
{{ include "athena-utils._registryPrefix" . }}/infra-chart-images/{{ .Values.infra.imageName }}:{{ .Chart.Version }}
{{- end -}}
{{- end -}}

{{/*
    Private helper function for localstack registry prefix
*/}}
{{- define "athena-utils.registryPrefixDockerhub" -}}
{{- .Values.global.registryPrefixDockerhub | default "harbor-repo.vmware.com"  -}}
{{- end -}}

{{/*
    Private helper function for all cluster wide values and the environment name.
*/}}
{{- define "athena-utils._clusterDefintionValues" -}}
env: {{ required "global.env is a required value. run `helm with --set global.env=$USER` for developers" .Values.global.env }}
registryPrefix: {{ include "athena-utils._registryPrefix" . }}
tfBucketNamePrefix: "mcs2-infra-chart-tfstate"
{{- if .Values.global.awsDeployment }}
awsDeployment: "true"
{{- if .Values.global.awsRegion }}
awsDefaultRegion: {{ .Values.global.awsRegion | quote }}
{{- end }}
{{- if .Values.global.awsVpcId }}
vpcId: {{ .Values.global.awsVpcId | quote }}
{{- end }}
{{- if .Values.global.awsSecurityGroupIds }}
securityGroupIds: {{ .Values.global.awsSecurityGroupIds | quote }}
{{- end }}
{{- if .Values.global.awsSubnetIds }}
subnetIds: {{ .Values.global.awsSubnetIds | quote }}
{{- end }}
{{- if .Values.global.awsIamTrustRelationships }}
awsIamTrustRelationships: {{ .Values.global.awsIamTrustRelationships | quote }}
{{- end }}
{{- if .Values.global.awsAccountNumber }}
awsAccountNumber: {{ .Values.global.awsAccountNumber | quote }}
{{- end }}
{{- else }}
awsDeployment: "false"
awsEndpointArg: "--endpoint-url=http://localstack:4566"
registryPrefixDockerhub: {{ include "athena-utils.registryPrefixDockerhub" . | quote }}
awsAccountNumber: "000000000000"
{{- end }}
{{- end -}}


{{/*
    Private helper function for all common inputs config values
*/}}
{{- define "athena-utils._commonConfigValues" -}}
infraNamespace: {{ include "athena-utils.infraNamespace" . }}
appsNamespace: {{ include "athena-utils.appsNamespace" . }}
releaseName: {{ .Release.Name }}
chartName: {{ .Chart.Name }}
chartVersion: {{ .Chart.Version }}
sguid: {{ include "athena-utils.sguid" . }}
{{- end -}}

{{/*
Common output configuration for all charts
 */}}
{{- define "athena-utils.outputConfig" -}}
{{ include "athena-utils._clusterDefintionValues" . }}
{{ include "athena-utils._commonConfigValues" . }}
{{- end -}}

{{/*
Common input configuration for all charts
 */}}
{{- define "athena-utils.inputConfig" -}}
{{ include "athena-utils._clusterDefintionValues" . }}
{{ include "athena-utils._commonConfigValues" . }}
namingPrefix: {{ include "athena-utils.namingPrefix" . }}
{{- if .Values.global.awsDeployment }}
externalNamingPrefix: {{ include "athena-utils.externalNamingPrefix" . }}
{{- if .Values.global.awsVpcId }}
vpc_id: {{ .Values.global.awsVpcId | quote }}
{{- end }}
{{- if .Values.global.awsSecurityGroupIds }}
security_group_ids: {{ .Values.global.awsSecurityGroupIds | quote }}
{{- end }}
{{- if .Values.global.awsSubnetIds }}
subnet_ids: {{ .Values.global.awsSubnetIds | quote }}
{{- end }}
{{- else }}
externalNamingPrefix: {{ include "athena-utils.namingPrefix" . }}-local
{{- end }}
{{- if .Values.global.tfVersion }}
tfVersion: {{ .Values.global.tfVersion | quote }}
{{- end }}
s3BucketKey: {{ include "athena-utils.s3BucketKey" . }}
forceDeploy: {{ .Values.global.forceDeploy | default false | quote }}
policyScan: {{ .Values.global.policyScan  | default false | quote }}
{{- end -}}

{{/*
Common input Terraform Vars for all charts
 */}}
{{- define "athena-utils.inputTfVars" -}}
{{- if .Values.global.awsDeployment }}
{{- if .Values.global.awsVpcId }}
TF_VAR_vpc_id: {{ .Values.global.awsVpcId | quote }}
{{- end }}
{{- if .Values.global.awsSecurityGroupIds }}
TF_VAR_security_group_ids: {{ .Values.global.awsSecurityGroupIds | quote }}
{{- end }}
{{- if .Values.global.awsSubnetIds }}
TF_VAR_subnet_ids: {{ .Values.global.awsSubnetIds | quote }}
{{- end }}
{{- end }}
{{- end -}}

{{/*
    Create chart name and version as used by the chart label.
*/}}
{{- define "athena-utils.chart" -}}
  {{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{- define "athena-utils.name" -}}
  {{- .Release.Name | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
    Common labels
*/}}
{{- define "athena-utils.labels" -}}
{{ include "athena-utils.selectorLabels" . }}
sbu.vmware.com/sguid: {{ include "athena-utils.sguid" . }}
sbu.vmware.com/stage: {{ .Values.global.envCategory | default "dev" }}
sbu.vmware.com/sku: {{ include "athena-utils.sku" . }}
helm.sh/chart: {{ include "athena-utils.chart" . }}
{{- if .Chart.Version }}
app.kubernetes.io/version: {{ .Chart.Version | quote }}
opa/version: 1.5.1
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
app.kubernetes.io/component: athena
app.kubernetes.io/instance: {{ include "athena-utils.externalNamingPrefix" . }}
app.kubernetes.io/part-of: {{ include "athena-utils.sku" . }}
{{- end -}}

{{/*
    Common Annotations
*/}}
{{- define "athena-utils.annotations" -}}
sbu.vmware.com/owner: {{ required "You must specify the 'owner'" .Values.standardTags.owner }}
sbu.vmware.com/sguid: {{ include "athena-utils.sguid" . }}
sbu.vmware.com/src_url: {{ .Values.src_url | default "https://gitlab.bit9.local/mcs2/infrastructure-charts" }}
sbu.vmware.com/stage: {{ .Values.global.envCategory | default "dev" }}
sbu.vmware.com/sku: {{ include "athena-utils.sku" . }}
sbu.vmware.com/chart-type: infrastructure
{{- end -}}

{{/*
  Selector labels
*/}}
{{- define "athena-utils.selectorLabels" -}}
app.kubernetes.io/name: {{ .Chart.Name }}
app.kubernetes.io/release: {{ .Release.Name }}
{{- end -}}

{{/*
  Resource Settings
*/}}
{{- define "athena-utils.resourceValues" -}}
requests:
    cpu: {{ .Values.infra.resources.requests.cpu }}
    memory: {{ .Values.infra.resources.requests.memory }}
    ephemeral-storage: {{ .Values.infra.resources.requests.ephemeral_storage }}
limits:
    memory: {{ .Values.infra.resources.limits.memory }}
    ephemeral-storage: {{ .Values.infra.resources.limits.ephemeral_storage }}
{{- end -}}

{{/*
  Security Context Settings

  These are the same across every chart
  - Check settings for runAsUser and runAsGroup in ../../Dockerfile
  - readOnlyRootFilesystem is false because we write values to an auto tfvars file
  - runAsNonRoot is true, check settings for runAsUser in ../../Dockerfile
*/}}
{{- define "athena-utils.securityContextValues" -}}
runAsUser: 1000
runAsGroup: 1000
runAsNonRoot: true
readOnlyRootFilesystem: false
{{- end -}}
